pyMETHES
========

A Monte Carlo simulation of electron transport in low temperature plasmas.

Python version of the MATLAB's `METHES package`_


License
-------
GNU General Public License v3 (GPLv3)


.. _METHES package: https://fr.lxcat.net/download/METHES/
